@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 
 package namespace::local;
 
-our $VERSION = '0.07_06';
+our $VERSION = '0.07_07';
 
 =head1 NAME
 
@@ -122,7 +122,7 @@ The following symbols are not touched by this module, to avoid breaking things:
 
 =item * Arrays: C<@CARP_NOT>, C<@EXPORT>, C<@EXPORT_OK>, C<@ISA>;
 
-=item * Scalars: C<$AUTOLOAD>, C<$DESTROY>*, C<$a>, C<$b>;
+=item * Scalars: C<$AUTOLOAD>, C<$a>, C<$b>;
 
 =item * Files: C<DATA>, C<STDERR>, C<STDIN>, C<STDOUT>;
 
@@ -130,9 +130,6 @@ The following symbols are not touched by this module, to avoid breaking things:
 
 =back
 
-*C<$DESTROY> is not a special variable, however,
-changing it was causing segfault in Perl 5.10.1
-
 This list is likely incomplete, and may grow in the future.
 
 =head1 METHOD/FUNCTIONS
@@ -236,7 +233,7 @@ sub new {
     $opt{touch_not}{$_}{ARRAY}++  for qw( CARP_NOT EXPORT EXPORT_OK ISA );
     $opt{touch_not}{$_}{CODE}++   for qw( AUTOLOAD DESTROY import );
     $opt{touch_not}{$_}{IO}++     for qw( DATA STDERR STDIN STDOUT );
-    $opt{touch_not}{$_}{SCALAR}++ for qw( AUTOLOAD DESTROY a b );
+    $opt{touch_not}{$_}{SCALAR}++ for qw( AUTOLOAD a b );
 
     return bless \%opt, $class;
 };
@@ -426,7 +423,7 @@ sub replace_symbols {
     return unless keys %$diff;
 
     # apply change
-    $self->message( "package $self->{target} to be altered: ".dump_table($diff) )
+    $self->message( "package $self->{target} to be altered: ".dump_table($diff, $old_table) )
         if DEBUG;
 
     $self->write_symbols( $diff );
@@ -508,6 +505,10 @@ sub table_diff {
             # if we cannot avoid overwriting,
             # make sure to copy ALL skipped values we know of
             $diff->{$name}{$_} = $old->{$_} for keys %$skip;
+
+            # removing a scalar copletely didn't work very well on Perl 5.10.1,
+            # causing segfaults in unrelated places.
+            $diff->{$name}{SCALAR} ||= \undef;
         };
     };
 
@@ -600,13 +601,15 @@ sub write_symbols {
 ### Logging
 
 sub dump_table {
-    my $table = shift;
+    my ($table, $old_table) = @_;
 
     my @out;
     foreach my $name( sort keys %$table ) {
         my $glob = $table->{$name};
         foreach my $type( sort keys %$glob ) {
             push @out, "*$name\{$type\}=".($glob->{$type} || 'undef');
+            $out[-1] .= sprintf "[was: %s]", $old_table->{$name}{$type} || 'undef'
+                if $old_table;
         };
     };
 
